@@ -172,6 +172,12 @@ options:
       - running
       - exited
       - paused
+  tty:
+    description:
+      - Allocate TTY to container
+    required: False
+    default: False
+    type: bool
 author: Sam Yaple
 '''
 
@@ -589,7 +595,7 @@ class DockerWorker(object):
             'image': self.params.get('image'),
             'name': self.params.get('name'),
             'volumes': volumes,
-            'tty': True
+            'tty': self.params.get('tty'),
         }
 
     def create_container(self):
@@ -772,7 +778,8 @@ def generate_module():
         tls_key=dict(required=False, type='str'),
         tls_cacert=dict(required=False, type='str'),
         volumes=dict(required=False, type='list'),
-        volumes_from=dict(required=False, type='list')
+        volumes_from=dict(required=False, type='list'),
+        tty=dict(required=False, type='bool', default=False),
     )
     required_if = [
         ['action', 'pull_image', ['image']],
