@@ -50,11 +50,14 @@ install_type = ${INSTALL_TYPE}
 profile = gate
 registry = 127.0.0.1:4000
 push = true
+logs_dir = /tmp/logs/build
 
 [profiles]
 gate = ${GATE_IMAGES}
 EOF
 
+mkdir -p /tmp/logs/build
+
     if [[ "${DISTRO}" == "Debian" ]]; then
         # Infra does not sign their mirrors so we ignore gpg signing in the gate
         echo "RUN echo 'APT::Get::AllowUnauthenticated \"true\";' > /etc/apt/apt.conf" | sudo tee -a /etc/kolla/header
@@ -83,7 +86,7 @@ function setup_ansible {
     RAW_INVENTORY=/etc/kolla/inventory
 
     # TODO(SamYaple): Move to virtualenv
-    sudo -H pip install -U "ansible>=2,<2.4" "docker>=2.0.0" "python-openstackclient" "python-neutronclient" "ara"
+    sudo -H pip install -U "ansible>=2,<2.4" "docker>=2.0.0" "python-openstackclient" "ara<0.16" "cmd2<0.9.0"
     detect_distro
 
     sudo mkdir /etc/ansible
@@ -121,7 +124,7 @@ function sanity_check {
     # https://bugs.launchpad.net/oslo.cache/+bug/1590779
     sudo docker restart memcached
     nova --debug service-list
-    neutron --debug agent-list
+    openstack --debug network agent list
     tools/init-runonce
     nova --debug boot --poll --image $(openstack image list | awk '/cirros/ {print $2}') --nic net-id=$(openstack network list | awk '/demo-net/ {print $2}') --flavor 1 kolla_boot_test
 
@@ -171,6 +174,7 @@ tools/kolla-ansible -i ${RAW_INVENTORY} -vvv prechecks > /tmp/logs/ansible/prech
 # service in CI
 tools/kolla-ansible -i ${RAW_INVENTORY} -vvv deploy > /tmp/logs/ansible/deploy
 tools/kolla-ansible -i ${RAW_INVENTORY} -vvv post-deploy > /tmp/logs/ansible/post-deploy
+tools/kolla-ansible -i ${RAW_INVENTORY} -vvv check > /tmp/logs/ansible/check-deploy
 
 # Test OpenStack Environment
 # TODO: use kolla-ansible check when it's ready
@@ -180,13 +184,12 @@ sanity_check
 # TODO(jeffrey4l): make some configure file change and
 # trigger a real reconfigure
 tools/kolla-ansible -i ${RAW_INVENTORY} -vvv reconfigure >  /tmp/logs/ansible/post-deploy
+tools/kolla-ansible -i ${RAW_INVENTORY} -vvv check > /tmp/logs/ansible/check-reconfigure
 # TODO(jeffrey4l): need run a real upgrade
 tools/kolla-ansible -i ${RAW_INVENTORY} -vvv upgrade > /tmp/logs/ansible/upgrade
+tools/kolla-ansible -i ${RAW_INVENTORY} -vvv check > /tmp/logs/ansible/check-upgrade
 
 # run prechecks again
 tools/kolla-ansible -i ${RAW_INVENTORY} -vvv prechecks > /tmp/logs/ansible/prechecks2
 
-ara generate html /tmp/logs/playbook_reports/
-gzip --recursive --best /tmp/logs/playbook_reports/
-
 check_failure
